Django WalletOne
================

.. image:: https://img.shields.io/pypi/v/django-walletone.svg
    :target: https://pypi.python.org/pypi/django-walletone/

.. image:: https://travis-ci.org/otov4its/django-walletone.svg?branch=master
    :target: https://travis-ci.org/otov4its/django-walletone

.. image:: https://readthedocs.org/projects/django-walletone/badge/?version=latest
    :target: http://django-walletone.readthedocs.org/en/latest/?badge=latest

.. image:: https://coveralls.io/repos/github/otov4its/django-walletone/badge.svg?branch=master
    :target: https://coveralls.io/github/otov4its/django-walletone

|

Django WalletOne is a pluggable application that integrates
with WalletOne online payments provider.

Django WalletOne supports Django 1.7 to 1.9 on Python 2.7, 3.4.

|

See https://django-walletone.readthedocs.org/ for application documentation.

See https://www.walletone.com/en/merchant/documentation/ for
native WalletOne documentation.
